// Aufsetzen eines Webservers, der eine asynchron aktualisierte Temperatur bereit stellt, Ajax.
// Der Code wurde von https://circuits4you.com/2018/02/04/esp8266-ajax-update-part-of-web-page-without-refreshing/ inspiriert.
//---- Für die Ersteinrichtung -----
// Die Resource für den Arduino Boardmanager lautet:http://arduino.esp8266.com/stable/package_esp8266com_index.json
// Der Standardtreiber für den ESP8266 ist unter https://www.silabs.com/developers/usb-to-uart-bridge-vcp-drivers bereitgestellt.


#include <ESP8266WiFi.h>
#include <WiFiClient.h>
#include <ESP8266WebServer.h>
#include <ESP8266mDNS.h>
#include <OneWire.h>
#include <DallasTemperature.h>
 
#include "index.h" // Hiermit wird eine Internetseite mit Javascript geladen. Die index.h muss sich im gleichen Verzeichnis befinden, wie die Programmdatei.
 
#define LED 2  // Pin 2 steuert die LED auf dem Board an.
 
//Der ESP arbeitet als Access Point (AP). Netzwerkkennung, das Passwort zum AP und der Hostname wird configuriert.
const char* ssid = "WMMSYS_TEMP1";
const char* password = "123456789";
const char* host = "mmsys";

float temperature;
long prevMillis=0;
ESP8266WebServer server(80); //Öffnet den Server auf Port 80

//Initialisierung der One Wire Kommunikation und des Temperatursensor
OneWire oneWire(D5);
DallasTemperature sensors(&oneWire);

void handleRoot() {
 server.send_P(200, "text/html", MAIN_page); //Wenn der Client auf den Server zugreift soll die MAIN_page angezeigt werden, welche in index.h definiert ist.
}
 
void handleDallas() {
 String ret = String(temperature);
 server.send(200, "text/plane", ret); //Sendet die temperatur auf Anfrage an den Client.
}
//Setup
void setup(void){
  //Beginne serielle Kommunikation mit einer Baud-Rate von 115200.
  Serial.begin(115200);
  //Setze LED als Ausgang.
  pinMode(LED,OUTPUT); 
  delay(10);
  //Konfiguriere Sensor.
  sensors.begin();
  sensors.setResolution(12);
  //Starte AP.
  WiFi.mode(WIFI_AP);
  WiFi.softAP(ssid, password);
  delay(100);
  //Übermittlung der Netzwerkkennung und der IP-Adresse über Serielle Kommunikation. Standard-IP ist 192.168.4.1
  Serial.print("SSID:");
  Serial.println(ssid);
  Serial.print("IP:");
  Serial.println(WiFi.softAPIP());
  //Initialisiere den MDNS-Service. Dieser bewirkt, dass man in der Adresszeile des Browsers mmsys.local statt der IP eingeben kann. 
  //Dies wird aber nicht immer unterstützt. Dann in die Adresszeile 192.168.4.1 eingeben.
  MDNS.begin(host);
  MDNS.addService("http", "tcp", 80);
  //Konfiguration Server
  server.on("/", handleRoot);      //Hier wird konfiguriert was passiert, wenn der Server vom Browser angesteuert wird. In diesem Fall wird die Hauptseite Main_page übermittelt (Funktion handleRoot).
  server.on("/readTemp", handleDallas); //Ruft man server/readTemp auf, so wird die aktuelle Temperatur zurück gegeben (Funktion handleDallas).
 
  server.begin();                  //Startet den Server
  Serial.println("HTTP server started");
}

void loop(void){
  unsigned long currentMillis=millis();
  server.handleClient();          //Bearbeitet die Anfragen der Clients.
  //Nichtblockierendes Abfragen der Temperatur mit 1Hz.
  if(currentMillis-prevMillis>1000){
    sensors.requestTemperatures();
    prevMillis=currentMillis;
    temperature = sensors.getTempCByIndex(0);
  }
  
}
